@@ -8,23 +8,17 @@ package RDF::RDFa::Generator;
 
 use 5.008;
 use strict;
+
 use warnings;
 
-our $VERSION = '0.191_02';
+
+our $VERSION = '0.199_01';
 
 use RDF::RDFa::Generator::HTML::Head;
 use RDF::RDFa::Generator::HTML::Hidden;
 use RDF::RDFa::Generator::HTML::Pretty;
-use RDF::Trine;
+use Carp;
 
-BEGIN
-{
-	$RDF::Trine::Serializer::serializer_names{ 'rdfa' }   = __PACKAGE__;
-	foreach my $type (qw(application/xhtml+xml text/html))
-	{
-		$RDF::Trine::Serializer::media_types{ $type }   = __PACKAGE__;
-	}
-}
 
 =head1 DESCRIPTION
 
@@ -46,7 +40,7 @@ Options include:
 
 =item * B<base> - the base URL where the output data will be published. This allows in some cases for the generated RDFa to include relative URIs.
 
-=item * B<data_context> - if non-null, a URI (string) which indicates the context (named graph) containing the data to generate RDFa for.
+=item * B<data_context> - if non-null, an L<Attean> Blank or IRI object or an L<RDF::Trine::Node> which indicates the context (named graph) containing the data to generate RDFa for.
 
 =item * B<namespaces> - a {prefix=>uri} hashref of preferred CURIE prefixes. 
 
@@ -151,44 +145,30 @@ sub nodes
 
 =back
 
-Additionally the methods C<serialize_model_to_file>, C<serialize_model_to_string>,
-C<serialize_iterator_to_file> and C<serialize_iterator_to_string> are provided for
-compatibility with the L<RDF::Trine::Serializer> interface.
+=head1 NOTE
+
+The methods C<serialize_model_to_file>, C<serialize_model_to_string>,
+C<serialize_iterator_to_file> and C<serialize_iterator_to_string> that
+were provided for compatibility with the L<RDF::Trine::Serializer>
+interface have been moved to a module L<RDF::Trine::Serializer::RDFa>
+that has to be installed separately.
 
 =cut
 
-sub serialize_model_to_string
-{
-	my ($proto, $model) = @_;
-	return $proto->create_document($model)->toString;
+sub serialize_model_to_string {
+  croak 'serialize_model_to_string have been to moved RDF::Trine::Serializer::RDFa';
 }
 
-sub serialize_model_to_file
-{
-	my ($proto, $fh, $model) = @_;
-	print {$fh} $proto->create_document($model)->toString;
+sub serialize_model_to_file {
+  croak 'serialize_model_to_file have been to moved RDF::Trine::Serializer::RDFa';
 }
 
-sub serialize_iterator_to_string
-{
-	my ($proto, $iter) = @_;
-	my $model = RDF::Trine::Model->temporary_model;
-	while (my $st = $iter->next)
-	{
-		$model->add_statement($st);
-	}
-	return $proto->serialize_model_to_string($model);
+sub serialize_iterator_to_string {
+  croak 'serialize_iterator_to_string have been to moved RDF::Trine::Serializer::RDFa';
 }
 
-sub serialize_iterator_to_file
-{
-	my ($proto, $fh, $iter) = @_;
-	my $model = RDF::Trine::Model->temporary_model;
-	while (my $st = $iter->next)
-	{
-		$model->add_statement($st);
-	}
-	return $proto->serialize_model_to_file($fh, $model);
+sub serialize_iterator_to_file {
+  croak 'serialize_iterator_to_string have been to moved RDF::Trine::Serializer::RDFa';
 }
 
 1;
@@ -202,9 +182,7 @@ Please report any bugs to L<https://github.com/kjetilk/p5-rdf-rdfa-generator/iss
 =head1 SEE ALSO
 
 L<HTML::HTML5::Writer>, L<XML::LibXML>, L<RDF::RDFa::Parser>, L<RDF::Trine>,
-L<RDF::Prefixes>.
-
-L<http://www.perlrdf.org/>.
+L<URI::NamespaceMap>, L<Attean>.
 
 =head1 AUTHOR
 
@@ -214,7 +192,7 @@ Kjetil Kjernsmo E<lt>kjetilk@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (C) 2010 by Toby Inkster, 2017 Kjetil Kjernsmo
+Copyright (C) 2010 by Toby Inkster, 2017, 2018 Kjetil Kjernsmo
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8 or,
